#ifndef _INFRARED_H_
#define _INFRARED_H_

/*!
 * \file ir.h
 * \brief Interface to an infrared receiver.
 *
 * www.klkl.de
 *
 * \verbatim
 *
 * Version 1.0 klkl 10.10.2010
 *
 * \endverbatim
 */

/*!
 * \brief has to be called once for initialization.
 *
 * Configures and starts a continuously running timer interrupt, which scans
 * the IR-input.
 *
 * The application must call IR_Read() to get the code of a IR-receive.
 */
extern void IR_Init(void);

/*!
 * \brief get one received command
 *
 * \param tmo maximum number of milliseconds to wait.
 *
 * \return >=1 if a command has been received, 0 if not.
 */
extern unsigned char IR_Read(u_long tmo);

/*!
 * \brief a thread which prints all the received IR-commands to stdout
 */
void IR_Receiver(void *arg) __attribute__ ((noreturn));

#endif	//_INFRARED_H_
